EvaluationError

Struct EvaluationError 

pub struct EvaluationError { /* private fields */ }
The error type for evaluating of a state using a predicate.

The primary source of this error is the Predicate::evaluate_state method. This error can represent one of three following occurences:

  1. A variable has a coefficient but not a value in the variable set
  2. A variable has a value in the variable set that is NaN
  3. A variable has a coefficient that is NaN

Values of this type can be queried for its cause, as well as the variable name causing the error.

Implementations

Source

impl EvaluationError

pub fn missing(name: &str) -> EvaluationError

Create an error for a missing variable

This method creates a clone of the name argument.

Example
let err = EvaluationError::missing("foo");
pub fn nan_value(name: &str) -> EvaluationError

Create an error for a variable with a NaN value

This method creates a clone of the name argument.

Example
let err = EvaluationError::nan_value("foo");
pub fn nan_coefficient(name: &str) -> EvaluationError

Create an error for a variable with a NaN coefficient

This method creates a clone of the name argument.

Example
let err = EvaluationError::nan_coefficient("foo");
pub fn name(&self) -> &str

Return the name of the variable that produced the error

pub fn kind(&self) -> ErrorKind

Return the ErrorKind for this error