pub struct EvaluationError { /* private fields */ }Expand description
The error type for evaluating of a state using a predicate.
The primary source of this error is the Predicate::evaluate_state method. This error can
represent one of three following occurences:
- A variable has a coefficient but not a value in the variable set
- A variable has a value in the variable set that is NaN
- A variable has a coefficient that is NaN
Values of this type can be queried for its cause, as well as the variable name causing the error.
Implementations
Sourceimpl EvaluationError
impl EvaluationError
Sourcepub fn missing(name: &str) -> EvaluationError
pub fn missing(name: &str) -> EvaluationError
Create an error for a missing variable
This method creates a clone of the name argument.
Example
let err = EvaluationError::missing("foo");Sourcepub fn nan_value(name: &str) -> EvaluationError
pub fn nan_value(name: &str) -> EvaluationError
Create an error for a variable with a NaN value
This method creates a clone of the name argument.
Example
let err = EvaluationError::nan_value("foo");Sourcepub fn nan_coefficient(name: &str) -> EvaluationError
pub fn nan_coefficient(name: &str) -> EvaluationError
Create an error for a variable with a NaN coefficient
This method creates a clone of the name argument.
Example
let err = EvaluationError::nan_coefficient("foo");Trait Implementations
Sourceimpl Clone for EvaluationError
impl Clone for EvaluationError
Sourcefn clone(&self) -> EvaluationError
fn clone(&self) -> EvaluationError
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EvaluationError
impl Debug for EvaluationError
Sourceimpl Display for EvaluationError
impl Display for EvaluationError
Sourceimpl Error for EvaluationError
impl Error for EvaluationError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0: use the Display impl or to_string()
Sourceimpl PartialEq for EvaluationError
impl PartialEq for EvaluationError
impl Eq for EvaluationError
impl StructuralPartialEq for EvaluationError